@@ -54,11 +54,19 @@ class CustomFieldsController < ApplicationController
 
   def update
     if @custom_field.update_attributes(params[:custom_field])
-      flash[:notice] = l(:notice_successful_update)
       call_hook(:controller_custom_fields_edit_after_save, :params => params, :custom_field => @custom_field)
-      redirect_back_or_default edit_custom_field_path(@custom_field)
+      respond_to do |format|
+        format.html {
+          flash[:notice] = l(:notice_successful_update)
+          redirect_back_or_default edit_custom_field_path(@custom_field)
+        }
+        format.js { render :nothing => true }
+      end
     else
-      render :action => 'edit'
+      respond_to do |format|
+        format.html { render :action => 'edit' }
+        format.js { render :nothing => true, :status => 422 }
+      end
     end
   end
 
