@@ -23,14 +23,10 @@ class IssueStatusesController < ApplicationController
   accept_api_auth :index
 
   def index
+    @issue_statuses = IssueStatus.sorted.to_a
     respond_to do |format|
-      format.html {
-        @issue_status_pages, @issue_statuses = paginate IssueStatus.sorted, :per_page => 25
-        render :action => "index", :layout => false if request.xhr?
-      }
-      format.api {
-        @issue_statuses = IssueStatus.order('position').to_a
-      }
+      format.html { render :layout => false if request.xhr? }
+      format.api
     end
   end
 
@@ -55,10 +51,18 @@ class IssueStatusesController < ApplicationController
   def update
     @issue_status = IssueStatus.find(params[:id])
     if @issue_status.update_attributes(params[:issue_status])
-      flash[:notice] = l(:notice_successful_update)
-      redirect_to issue_statuses_path(:page => params[:page])
+      respond_to do |format|
+        format.html {
+          flash[:notice] = l(:notice_successful_update)
+          redirect_to issue_statuses_path(:page => params[:page])
+        }
+        format.js { render :nothing => true }
+      end
     else
-      render :action => 'edit'
+      respond_to do |format|
+        format.html { render :action => 'edit' }
+        format.js { render :nothing => true, :status => 422 }
+      end
     end
   end
 
