@@ -174,7 +174,7 @@ class TimelogController < ApplicationController
   end
 
   def bulk_update
-    attributes = parse_params_for_bulk_time_entry_attributes(params)
+    attributes = parse_params_for_bulk_update(params[:time_entry])
 
     unsaved_time_entry_ids = []
     @time_entries.each do |time_entry|
@@ -271,11 +271,4 @@ private
     end
     scope
   end
-
-  def parse_params_for_bulk_time_entry_attributes(params)
-    attributes = (params[:time_entry] || {}).reject {|k,v| v.blank?}
-    attributes.keys.each {|k| attributes[k] = '' if attributes[k] == 'none'}
-    attributes[:custom_field_values].reject! {|k,v| v.blank?} if attributes[:custom_field_values]
-    attributes
-  end
 end
