@@ -30,14 +30,27 @@ module JournalsHelper
     editable = User.current.logged? && (User.current.allowed_to?(:edit_issue_notes, issue.project) || (journal.user == User.current && User.current.allowed_to?(:edit_own_issue_notes, issue.project)))
     links = []
     if !journal.notes.blank?
-      links << link_to(image_tag('comment.png'),
-                       {:controller => 'journals', :action => 'new', :id => issue, :journal_id => journal},
+      links << link_to(l(:button_quote),
+                       quoted_issue_path(issue, :journal_id => journal),
                        :remote => true,
                        :method => 'post',
-                       :title => l(:button_quote)) if options[:reply_links]
-      links << link_to_in_place_notes_editor(image_tag('edit.png'), "journal-#{journal.id}-notes",
-                                             { :controller => 'journals', :action => 'edit', :id => journal, :format => 'js' },
-                                                :title => l(:button_edit)) if editable
+                       :title => l(:button_quote),
+                       :class => 'icon-only icon-comment'
+                      ) if options[:reply_links]
+      links << link_to(l(:button_edit),
+                       edit_journal_path(journal),
+                       :remote => true,
+                       :method => 'get',
+                       :title => l(:button_edit),
+                       :class => 'icon-only icon-edit'
+                      ) if editable
+      links << link_to(l(:button_delete),
+                       journal_path(journal, :notes => ""),
+                       :remote => true,
+                       :method => 'put', :data => {:confirm => l(:text_are_you_sure)}, 
+                       :title => l(:button_delete),
+                       :class => 'icon-only icon-del'
+                      ) if editable
     end
     content << content_tag('div', links.join(' ').html_safe, :class => 'contextual') unless links.empty?
     content << textilizable(journal, :notes)
@@ -45,9 +58,4 @@ module JournalsHelper
     css_classes << " editable" if editable
     content_tag('div', content.html_safe, :id => "journal-#{journal.id}-notes", :class => css_classes)
   end
-
-  def link_to_in_place_notes_editor(text, field_id, url, options={})
-    onclick = "$.ajax({url: '#{url_for(url)}', type: 'get'}); return false;"
-    link_to text, '#', options.merge(:onclick => onclick)
-  end
 end
