@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -23,10 +23,6 @@ class Change < ActiveRecord::Base
   before_validation :replace_invalid_utf8_of_path
   attr_protected :id
 
-  def relative_path
-    changeset.repository.relative_path(path)
-  end
-
   def replace_invalid_utf8_of_path
     self.path      = Redmine::CodesetUtil.replace_invalid_utf8(self.path)
     self.from_path = Redmine::CodesetUtil.replace_invalid_utf8(self.from_path)
