@@ -24,7 +24,7 @@ class CustomField < ActiveRecord::Base
            :dependent => :delete_all
   has_many :custom_values, :dependent => :delete_all
   has_and_belongs_to_many :roles, :join_table => "#{table_name_prefix}custom_fields_roles#{table_name_suffix}", :foreign_key => "custom_field_id"
-  acts_as_list :scope => 'type = \'#{self.class}\''
+  acts_as_positioned
   serialize :possible_values
   store :format_store
 
