@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -18,29 +18,29 @@
 class Document < ActiveRecord::Base
   include Redmine::SafeAttributes
   belongs_to :project
-  belongs_to :category, :class_name => "DocumentCategory", :foreign_key => "category_id"
+  belongs_to :category, :class_name => "DocumentCategory"
   acts_as_attachable :delete_permission => :delete_documents
+  acts_as_customizable
 
   acts_as_searchable :columns => ['title', "#{table_name}.description"],
-                     :scope => preload(:project)
+                     :preload => :project
   acts_as_event :title => Proc.new {|o| "#{l(:label_document)}: #{o.title}"},
                 :author => Proc.new {|o| o.attachments.reorder("#{Attachment.table_name}.created_on ASC").first.try(:author) },
                 :url => Proc.new {|o| {:controller => 'documents', :action => 'show', :id => o.id}}
   acts_as_activity_provider :scope => preload(:project)
 
   validates_presence_of :project, :title, :category
-  validates_length_of :title, :maximum => 60
+  validates_length_of :title, :maximum => 255
   attr_protected :id
 
   after_create :send_notification
 
   scope :visible, lambda {|*args|
     joins(:project).
-    references(:project).
     where(Project.allowed_to_condition(args.shift || User.current, :view_documents, *args))
   }
 
-  safe_attributes 'category_id', 'title', 'description'
+  safe_attributes 'category_id', 'title', 'description', 'custom_fields', 'custom_field_values'
 
   def visible?(user=User.current)
     !user.nil? && user.allowed_to?(:view_documents, project)
@@ -61,6 +61,10 @@ class Document < ActiveRecord::Base
     @updated_on
   end
 
+  def notified_users
+    project.notified_users.reject {|user| !visible?(user)}
+  end
+
   private
 
   def send_notification
