@@ -245,6 +245,8 @@ class IssueQuery < Query
     add_available_filter "parent_id", :type => :tree, :label => :field_parent_issue
     add_available_filter "child_id", :type => :tree, :label => :label_subtask_plural
 
+    add_available_filter "issue_id", :type => :integer, :label => :label_issue
+
     Tracker.disabled_core_fields(trackers).each {|field|
       delete_available_filter field
     }
@@ -509,6 +511,20 @@ class IssueQuery < Query
     end
   end
 
+  def sql_for_issue_id_field(field, operator, value)
+    if operator == "="
+      # accepts a comma separated list of ids
+      ids = value.first.to_s.scan(/\d+/).map(&:to_i)
+      if ids.present?
+        "#{Issue.table_name}.id IN (#{ids.join(",")})"
+      else
+        "1=0"
+      end
+    else
+      sql_for_field("id", operator, value, Issue.table_name, "id")
+    end
+  end
+
   def sql_for_relations(field, operator, value, options={})
     relation_options = IssueRelation::TYPES[field]
     return relation_options unless relation_options
