@@ -310,6 +310,20 @@ class Mailer < ActionMailer::Base
       :subject => l(:mail_subject_lost_password, Setting.app_title)
   end
 
+  # Notifies user that his password was updated
+  def self.password_updated(user)
+    # Don't send a notification to the dummy email address when changing the password
+    # of the default admin account which is required after the first login
+    # TODO: maybe not the best way to handle this
+    return if user.admin? && user.login == 'admin' && user.mail == 'admin@example.net'
+
+    Mailer.security_notification(user,
+      message: :mail_body_password_updated,
+      title: :button_change_password,
+      url: {controller: 'my', action: 'password'}
+    ).deliver
+  end
+
   def register(token)
     set_language_if_valid(token.user.language)
     @token = token
@@ -318,6 +332,36 @@ class Mailer < ActionMailer::Base
       :subject => l(:mail_subject_register, Setting.app_title)
   end
 
+  def security_notification(recipients, options={})
+    redmine_headers 'Sender' => User.current.login
+    @user = Array(recipients).detect{|r| r.is_a? User }
+    set_language_if_valid(@user.try :language)
+    @message = l(options[:message],
+      field: (options[:field] && l(options[:field])),
+      value: options[:value]
+    )
+    @title = options[:title] && l(options[:title])
+    @url = options[:url] && (options[:url].is_a?(Hash) ? url_for(options[:url]) : options[:url])
+    mail :to => recipients,
+      :subject => "[#{Setting.app_title}] #{l(:mail_subject_security_notification)}"
+  end
+
+  def settings_updated(recipients, changes)
+    redmine_headers 'Sender' => User.current.login
+    @changes = changes
+    @url = url_for(controller: 'settings', action: 'index')
+    mail :to => recipients,
+      :subject => "[#{Setting.app_title}] #{l(:mail_subject_security_notification)}"
+  end
+
+	# Notifies admins about settings changes
+  def self.security_settings_updated(changes)
+    return unless changes.present?
+
+    users = User.active.where(admin: true).to_a
+    Mailer.settings_updated(users, changes).deliver
+  end
+
   def test_email(user)
     set_language_if_valid(user.language)
     @url = url_for(:controller => 'welcome')
