@@ -47,20 +47,25 @@ class User < Principal
         :order => %w(lastname firstname id),
         :setting_order => 4
       },
+    :lastnamefirstname => {
+        :string => '#{lastname}#{firstname}',
+        :order => %w(lastname firstname id),
+        :setting_order => 5
+      },
     :lastname_comma_firstname => {
         :string => '#{lastname}, #{firstname}',
         :order => %w(lastname firstname id),
-        :setting_order => 5
+        :setting_order => 6
       },
     :lastname => {
         :string => '#{lastname}',
         :order => %w(lastname id),
-        :setting_order => 6
+        :setting_order => 7
       },
     :username => {
         :string => '#{login}',
         :order => %w(login id),
-        :setting_order => 7
+        :setting_order => 8
       },
   }
 
@@ -92,6 +97,8 @@ class User < Principal
 
   attr_accessor :password, :password_confirmation, :generate_password
   attr_accessor :last_before_login_on
+  attr_accessor :remote_ip
+
   # Prevents unauthorized assignments
   attr_protected :login, :admin, :password, :password_confirmation, :hashed_password
 
@@ -112,11 +119,14 @@ class User < Principal
     end
   end
 
+  self.valid_statuses = [STATUS_ACTIVE, STATUS_REGISTERED, STATUS_LOCKED]
+
   before_validation :instantiate_email_address
   before_create :set_mail_notification
   before_save   :generate_password_if_needed, :update_hashed_password
   before_destroy :remove_references_before_destroy
-  after_save :update_notified_project_ids, :destroy_tokens
+  after_save :update_notified_project_ids, :destroy_tokens, :deliver_security_notification
+  after_destroy :deliver_security_notification
 
   scope :in_group, lambda {|group|
     group_id = group.is_a?(Group) ? group.id : group.to_i
@@ -502,7 +512,7 @@ class User < Principal
     if time_zone.nil?
       Date.today
     else
-      Time.now.in_time_zone(time_zone).to_date
+      time_zone.today
     end
   end
 
@@ -544,7 +554,7 @@ class User < Principal
     # No role on archived projects
     return [] if project.nil? || project.archived?
     if membership = membership(project)
-      membership.roles.dup
+      membership.roles.to_a
     elsif project.is_public?
       project.override_roles(builtin_role)
     else
@@ -829,11 +839,43 @@ class User < Principal
     Redmine::Utils.random_hex(16)
   end
 
+  # Send a security notification to all admins if the user has gained/lost admin privileges
+  def deliver_security_notification
+    options = {
+      field: :field_admin,
+      value: login,
+      title: :label_user_plural,
+      url: {controller: 'users', action: 'index'}
+    }
+
+    deliver = false
+    if (admin? && id_changed? && active?) ||    # newly created admin
+       (admin? && admin_changed? && active?) || # regular user became admin
+       (admin? && status_changed? && active?)   # locked admin became active again
+
+       deliver = true
+       options[:message] = :mail_body_security_notification_add
+
+    elsif (admin? && destroyed? && active?) ||      # active admin user was deleted
+          (!admin? && admin_changed? && active?) || # admin is no longer admin
+          (admin? && status_changed? && !active?)   # admin was locked
+
+          deliver = true
+          options[:message] = :mail_body_security_notification_remove
+    end
+
+    if deliver
+      users = User.active.where(admin: true).to_a
+      Mailer.security_notification(users, options).deliver
+    end
+  end
 end
 
 class AnonymousUser < User
   validate :validate_anonymous_uniqueness, :on => :create
 
+  self.valid_statuses = [STATUS_ANONYMOUS]
+
   def validate_anonymous_uniqueness
     # There should be only one AnonymousUser in the database
     errors.add :base, 'An anonymous user already exists.' if AnonymousUser.exists?
