@@ -71,12 +71,13 @@ module Redmine
       ::I18n.l(date.to_date, options)
     end
 
-    def format_time(time, include_date = true)
+    def format_time(time, include_date=true, user=nil)
       return nil unless time
+      user ||= User.current
       options = {}
       options[:format] = (Setting.time_format.blank? ? :time : Setting.time_format)
       time = time.to_time if time.is_a?(String)
-      zone = User.current.time_zone
+      zone = user.time_zone
       local = zone ? time.in_time_zone(zone) : (time.utc? ? time.localtime : time)
       (include_date ? "#{format_date(local)} " : "") + ::I18n.l(local, options)
     end
@@ -139,6 +140,7 @@ module Redmine
 
       module Implementation
         include ::I18n::Backend::Base
+        include ::I18n::Backend::Pluralization
 
         # Stores translations for the given locale in memory.
         # This uses a deep merge for the translations hash, so existing
