@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -24,9 +24,13 @@ module Redmine
         host = imap_options[:host] || '127.0.0.1'
         port = imap_options[:port] || '143'
         ssl = !imap_options[:ssl].nil?
+        starttls = !imap_options[:starttls].nil?
         folder = imap_options[:folder] || 'INBOX'
 
         imap = Net::IMAP.new(host, port, ssl)
+        if starttls
+          imap.starttls
+        end
         imap.login(imap_options[:username], imap_options[:password]) unless imap_options[:username].nil?
         imap.select(folder)
         imap.uid_search(['NOT', 'SEEN']).each do |uid|
