@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -40,12 +40,8 @@ class AttachmentsControllerTest < ActionController::TestCase
       assert_response :success
       assert_template 'diff'
       assert_equal 'text/html', @response.content_type
-      assert_tag 'th',
-        :attributes => {:class => /filename/},
-        :content => /issues_controller.rb\t\(révision 1484\)/
-      assert_tag 'td',
-        :attributes => {:class => /line-code/},
-        :content => /Demande créée avec succès/
+      assert_select 'th.filename', :text => /issues_controller.rb\t\(révision 1484\)/
+      assert_select 'td.line-code', :text => /Demande créée avec succès/
     end
     set_tmp_attachments_directory
   end
@@ -58,12 +54,8 @@ class AttachmentsControllerTest < ActionController::TestCase
         assert_response :success
         assert_template 'diff'
         assert_equal 'text/html', @response.content_type
-        assert_tag 'th',
-          :attributes => {:class => "filename"},
-          :content => /issues_controller.rb\t\(r\?vision 1484\)/
-        assert_tag 'td',
-          :attributes => {:class => /line-code/},
-          :content => /Demande cr\?\?e avec succ\?s/
+        assert_select 'th.filename', :text => /issues_controller.rb\t\(r\?vision 1484\)/
+        assert_select 'td.line-code', :text => /Demande cr\?\?e avec succ\?s/
       end
     end
     set_tmp_attachments_directory
@@ -77,12 +69,8 @@ class AttachmentsControllerTest < ActionController::TestCase
         assert_response :success
         assert_template 'diff'
         assert_equal 'text/html', @response.content_type
-        assert_tag 'th',
-          :attributes => {:class => "filename"},
-          :content => /issues_controller.rb\t\(révision 1484\)/
-        assert_tag 'td',
-          :attributes => {:class => /line-code/},
-          :content => /Demande créée avec succès/
+        assert_select 'th.filename', :text => /issues_controller.rb\t\(révision 1484\)/
+        assert_select 'td.line-code', :text => /Demande créée avec succès/
       end
     end
     set_tmp_attachments_directory
@@ -139,17 +127,16 @@ class AttachmentsControllerTest < ActionController::TestCase
     assert a.save
     assert_equal 'japanese-utf-8.txt', a.filename
 
-    str_japanese = "\xe6\x97\xa5\xe6\x9c\xac\xe8\xaa\x9e"
-    str_japanese.force_encoding('UTF-8') if str_japanese.respond_to?(:force_encoding)
+    str_japanese = "\xe6\x97\xa5\xe6\x9c\xac\xe8\xaa\x9e".force_encoding('UTF-8')
 
     get :show, :id => a.id
     assert_response :success
     assert_template 'file'
     assert_equal 'text/html', @response.content_type
-    assert_tag :tag => 'th',
-               :content => '1',
-               :attributes => { :class => 'line-num' },
-               :sibling => { :tag => 'td', :content => /#{str_japanese}/ }
+    assert_select 'tr#L1' do
+      assert_select 'th.line-num', :text => '1'
+      assert_select 'td', :text => /#{str_japanese}/
+    end
   end
 
   def test_show_text_file_replace_cannot_convert_content
@@ -165,10 +152,10 @@ class AttachmentsControllerTest < ActionController::TestCase
       assert_response :success
       assert_template 'file'
       assert_equal 'text/html', @response.content_type
-      assert_tag :tag => 'th',
-                 :content => '7',
-                 :attributes => { :class => 'line-num' },
-                 :sibling => { :tag => 'td', :content => /Demande cr\?\?e avec succ\?s/ }
+      assert_select 'tr#L7' do
+        assert_select 'th.line-num', :text => '7'
+        assert_select 'td', :text => /Demande cr\?\?e avec succ\?s/
+      end
     end
   end
 
@@ -185,27 +172,38 @@ class AttachmentsControllerTest < ActionController::TestCase
       assert_response :success
       assert_template 'file'
       assert_equal 'text/html', @response.content_type
-      assert_tag :tag => 'th',
-                 :content => '7',
-                 :attributes => { :class => 'line-num' },
-                 :sibling => { :tag => 'td', :content => /Demande créée avec succès/ }
+      assert_select 'tr#L7' do
+        assert_select 'th.line-num', :text => '7'
+        assert_select 'td', :text => /Demande créée avec succès/
       end
+    end
   end
 
-  def test_show_text_file_should_send_if_too_big
+  def test_show_text_file_should_show_other_if_too_big
     with_settings :file_max_size_displayed => 512 do
       Attachment.find(4).update_attribute :filesize, 754.kilobyte
       get :show, :id => 4
       assert_response :success
-      assert_equal 'application/x-ruby', @response.content_type
+      assert_template 'other'
+      assert_equal 'text/html', @response.content_type
     end
     set_tmp_attachments_directory
   end
 
+  def test_show_image
+    @request.session[:user_id] = 2
+    get :show, :id => 16
+    assert_response :success
+    assert_template 'image'
+    assert_equal 'text/html', @response.content_type
+    assert_select 'img.filecontent', :src => attachments(:attachments_010).filename
+  end
+
   def test_show_other
     get :show, :id => 6
-    assert_response :success
-    assert_equal 'application/octet-stream', @response.content_type
+    assert_template 'other'
+    assert_equal 'text/html', @response.content_type
+    assert_select '.nodata', :text => 'No preview available'
     set_tmp_attachments_directory
   end
 
@@ -219,7 +217,7 @@ class AttachmentsControllerTest < ActionController::TestCase
     @request.session[:user_id] = 2
     get :show, :id => 15
     assert_response :success
-    assert_tag 'h2', :content => /private.diff/
+    assert_select 'h2', :text => /private.diff/
     set_tmp_attachments_directory
   end
 
@@ -260,6 +258,19 @@ class AttachmentsControllerTest < ActionController::TestCase
     set_tmp_attachments_directory
   end
 
+  def test_download_js_file
+    set_tmp_attachments_directory
+    attachment = Attachment.create!(
+      :file => mock_file_with_options(:original_filename => "hello.js", :content_type => "text/javascript"),
+      :author_id => 2,
+      :container => Issue.find(1)
+    )
+
+    get :download, :id => attachment.id
+    assert_response :success
+    assert_equal 'text/javascript', @response.content_type
+  end
+
   def test_download_version_file_with_issue_tracking_disabled
     Project.find(1).disable_module! :issue_tracking
     get :download, :id => 9
@@ -275,6 +286,15 @@ class AttachmentsControllerTest < ActionController::TestCase
     set_tmp_attachments_directory
   end
 
+  def test_download_should_assign_better_content_type_than_application_octet_stream
+    Attachment.find(4).update! :content_type => "application/octet-stream"
+
+    get :download, :id => 4
+    assert_response :success
+    assert_equal 'text/x-ruby', @response.content_type
+    set_tmp_attachments_directory
+  end
+
   def test_download_missing_file
     get :download, :id => 2
     assert_response 404
@@ -340,6 +360,69 @@ class AttachmentsControllerTest < ActionController::TestCase
     puts '(ImageMagick convert not available)'
   end
 
+  def test_edit
+    @request.session[:user_id] = 2
+    get :edit, :object_type => 'issues', :object_id => '2'
+    assert_response :success
+    assert_template 'edit'
+
+    container = Issue.find(2)
+    assert_equal container, assigns(:container)
+    assert_equal container.attachments.size, assigns(:attachments).size
+
+    assert_select 'form[action=?]', '/attachments/issues/2' do
+      assert_select 'tr#attachment-4' do
+        assert_select 'input[name=?][value=?]', 'attachments[4][filename]', 'source.rb'
+        assert_select 'input[name=?][value=?]', 'attachments[4][description]', 'This is a Ruby source file'
+      end
+    end
+  end
+
+  def test_edit_invalid_container_class_should_return_404
+    get :edit, :object_type => 'nuggets', :object_id => '3'
+    assert_response 404
+  end
+
+  def test_edit_invalid_object_should_return_404
+    get :edit, :object_type => 'issues', :object_id => '999'
+    assert_response 404
+  end
+
+  def test_edit_for_object_that_is_not_visible_should_return_403
+    get :edit, :object_type => 'issues', :object_id => '4'
+    assert_response 403
+  end
+
+  def test_update
+    @request.session[:user_id] = 2
+    patch :update, :object_type => 'issues', :object_id => '2', :attachments => {
+        '1' => {:filename => 'newname.text', :description => ''},
+        '4' => {:filename => 'newname.rb', :description => 'Renamed'},
+      }
+
+    assert_response 302
+    attachment = Attachment.find(4)
+    assert_equal 'newname.rb', attachment.filename
+    assert_equal 'Renamed', attachment.description
+  end
+
+  def test_update_with_failure
+    @request.session[:user_id] = 2
+    patch :update, :object_type => 'issues', :object_id => '3', :attachments => {
+        '1' => {:filename => '', :description => ''},
+        '4' => {:filename => 'newname.rb', :description => 'Renamed'},
+      }
+
+    assert_response :success
+    assert_template 'edit'
+    assert_select_error /file cannot be blank/i
+
+    # The other attachment should not be updated
+    attachment = Attachment.find(4)
+    assert_equal 'source.rb', attachment.filename
+    assert_equal 'This is a Ruby source file', attachment.description
+  end
+
   def test_destroy_issue_attachment
     set_tmp_attachments_directory
     issue = Issue.find(3)
