@@ -132,6 +132,22 @@ class RolesControllerTest < ActionController::TestCase
     assert_equal [:edit_project], role.permissions
   end
 
+  def test_update_trackers_permissions
+    put :update, :id => 1, :role => {
+      :permissions_all_trackers => {'add_issues' => '0'},
+      :permissions_tracker_ids => {'add_issues' => ['1', '3', '']}
+    }
+
+    assert_redirected_to '/roles'
+    role = Role.find(1)
+
+    assert_equal({'add_issues' => '0'}, role.permissions_all_trackers)
+    assert_equal({'add_issues' => ['1', '3']}, role.permissions_tracker_ids)
+
+    assert_equal false, role.permissions_all_trackers?(:add_issues)
+    assert_equal [1, 3], role.permissions_tracker_ids(:add_issues).sort
+  end
+
   def test_update_with_failure
     put :update, :id => 1, :role => {:name => ''}
     assert_response :success
@@ -181,28 +197,28 @@ class RolesControllerTest < ActionController::TestCase
   end
 
   def test_move_highest
-    put :update, :id => 3, :role => {:move_to => 'highest'}
+    put :update, :id => 3, :role => {:position => 1}
     assert_redirected_to '/roles'
     assert_equal 1, Role.find(3).position
   end
 
   def test_move_higher
     position = Role.find(3).position
-    put :update, :id => 3, :role => {:move_to => 'higher'}
+    put :update, :id => 3, :role => {:position => position - 1}
     assert_redirected_to '/roles'
     assert_equal position - 1, Role.find(3).position
   end
 
   def test_move_lower
     position = Role.find(2).position
-    put :update, :id => 2, :role => {:move_to => 'lower'}
+    put :update, :id => 2, :role => {:position => position + 1}
     assert_redirected_to '/roles'
     assert_equal position + 1, Role.find(2).position
   end
 
   def test_move_lowest
-    put :update, :id => 2, :role => {:move_to => 'lowest'}
+    put :update, :id => 2, :role => {:position => Role.givable.count}
     assert_redirected_to '/roles'
-    assert_equal Role.count, Role.find(2).position
+    assert_equal Role.givable.count, Role.find(2).position
   end
 end
