@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@ class TimeEntryReportsControllerTest < ActionController::TestCase
   tests TimelogController
 
   fixtures :projects, :enabled_modules, :roles, :members, :member_roles,
+           :email_addresses,
            :issues, :time_entries, :users, :trackers, :enumerations,
            :issue_statuses, :custom_fields, :custom_values,
            :projects_trackers, :custom_fields_trackers,
@@ -37,16 +38,14 @@ class TimeEntryReportsControllerTest < ActionController::TestCase
     get :report, :project_id => 'ecookbook'
     assert_response :success
     assert_template 'report'
-    assert_tag :form,
-      :attributes => {:action => "/projects/ecookbook/time_entries/report", :id => 'query_form'}
+    assert_select 'form#query_form[action=?]', '/projects/ecookbook/time_entries/report'
   end
 
   def test_report_all_projects
     get :report
     assert_response :success
     assert_template 'report'
-    assert_tag :form,
-      :attributes => {:action => "/time_entries/report", :id => 'query_form'}
+    assert_select 'form#query_form[action=?]', '/time_entries/report'
   end
 
   def test_report_all_projects_denied
@@ -80,7 +79,7 @@ class TimeEntryReportsControllerTest < ActionController::TestCase
     assert_template 'report'
     assert_not_nil assigns(:report)
     assert_equal "162.90", "%.2f" % assigns(:report).total_hours
-    assert_tag :tag => 'th', :content => '2007-03-12'
+    assert_select 'th', :text => '2007-03-12'
   end
 
   def test_report_one_criteria
@@ -130,13 +129,12 @@ class TimeEntryReportsControllerTest < ActionController::TestCase
   end
 
   def test_report_at_issue_level
-    get :report, :project_id => 1, :issue_id => 1, :columns => 'month', :from => "2007-01-01", :to => "2007-12-31", :criteria => ["user", "activity"]
+    get :report, :issue_id => 1, :columns => 'month', :from => "2007-01-01", :to => "2007-12-31", :criteria => ["user", "activity"]
     assert_response :success
     assert_template 'report'
     assert_not_nil assigns(:report)
     assert_equal "154.25", "%.2f" % assigns(:report).total_hours
-    assert_tag :form,
-      :attributes => {:action => "/projects/ecookbook/issues/1/time_entries/report", :id => 'query_form'}
+    assert_select 'form#query_form[action=?]', '/issues/1/time_entries/report'
   end
 
   def test_report_by_week_should_use_commercial_year
@@ -209,8 +207,8 @@ class TimeEntryReportsControllerTest < ActionController::TestCase
     get :report, :project_id => 1, :criteria => ['status']
     assert_response :success
     assert_template 'report'
-    assert_tag :tag => 'th', :content => 'Status'
-    assert_tag :tag => 'td', :content => 'New'
+    assert_select 'th', :text => 'Status'
+    assert_select 'td', :text => 'New'
   end
 
   def test_report_all_projects_csv_export
@@ -239,7 +237,6 @@ class TimeEntryReportsControllerTest < ActionController::TestCase
   end
 
   def test_csv_big_5
-    Setting.default_language = "zh-TW"
     str_utf8  = "\xe4\xb8\x80\xe6\x9c\x88".force_encoding('UTF-8')
     str_big5  = "\xa4@\xa4\xeb".force_encoding('Big5')
     user = User.find_by_id(3)
@@ -259,9 +256,11 @@ class TimeEntryReportsControllerTest < ActionController::TestCase
     assert_equal 7.3, te2.hours
     assert_equal 3, te2.user_id
 
-    get :report, :project_id => 1, :columns => 'day',
-        :from => "2011-11-11", :to => "2011-11-11",
-        :criteria => ["user"], :format => "csv"
+    with_settings :default_language => "zh-TW" do
+      get :report, :project_id => 1, :columns => 'day',
+          :from => "2011-11-11", :to => "2011-11-11",
+          :criteria => ["user"], :format => "csv"
+    end
     assert_response :success
     assert_equal 'text/csv; header=present', @response.content_type
     lines = @response.body.chomp.split("\n")    
@@ -281,7 +280,6 @@ class TimeEntryReportsControllerTest < ActionController::TestCase
   end
 
   def test_csv_cannot_convert_should_be_replaced_big_5
-    Setting.default_language = "zh-TW"
     str_utf8  = "\xe4\xbb\xa5\xe5\x86\x85".force_encoding('UTF-8')
     user = User.find_by_id(3)
     user.firstname = str_utf8
@@ -300,9 +298,11 @@ class TimeEntryReportsControllerTest < ActionController::TestCase
     assert_equal 7.3, te2.hours
     assert_equal 3, te2.user_id
 
-    get :report, :project_id => 1, :columns => 'day',
-        :from => "2011-11-11", :to => "2011-11-11",
-        :criteria => ["user"], :format => "csv"
+    with_settings :default_language => "zh-TW" do
+      get :report, :project_id => 1, :columns => 'day',
+          :from => "2011-11-11", :to => "2011-11-11",
+          :criteria => ["user"], :format => "csv"
+    end
     assert_response :success
     assert_equal 'text/csv; header=present', @response.content_type
     lines = @response.body.chomp.split("\n")    
@@ -310,12 +310,7 @@ class TimeEntryReportsControllerTest < ActionController::TestCase
     s1 = "\xa5\xce\xa4\xe1,2011-11-11,\xa4u\xae\xc9\xc1`\xadp".force_encoding('Big5')
     assert_equal s1, lines.first
     # Total row
-    s2 = ""
-    if RUBY_PLATFORM == 'java'
-      s2 = "??"
-    else
-      s2 = "\xa5H?".force_encoding('Big5')
-    end
+    s2 = "\xa5H?".force_encoding('Big5')
     assert_equal "#{s2} #{user.lastname},7.30,7.30", lines[1]
   end
 
@@ -349,7 +344,7 @@ class TimeEntryReportsControllerTest < ActionController::TestCase
       assert_equal "#{user.firstname} #{user.lastname};7,30;7,30", lines[1]
       assert_equal "#{s2};7,30;7,30", lines[2]
 
-      str_fr = "Fran\xc3\xa7ais".force_encoding('UTF-8')
+      str_fr = "French (Fran\xc3\xa7ais)".force_encoding('UTF-8')
       assert_equal str_fr, l(:general_lang_name)
       assert_equal 'ISO-8859-1', l(:general_csv_encoding)
       assert_equal ';', l(:general_csv_separator)
