@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -21,6 +21,7 @@ class WelcomeControllerTest < ActionController::TestCase
   fixtures :projects, :news, :users, :members
 
   def setup
+    Setting.default_language = 'en'
     User.current = nil
   end
 
@@ -29,33 +30,27 @@ class WelcomeControllerTest < ActionController::TestCase
     assert_response :success
     assert_template 'index'
     assert_not_nil assigns(:news)
-    assert_not_nil assigns(:projects)
-    assert !assigns(:projects).include?(Project.where(:is_public => false).first)
   end
 
   def test_browser_language
-    Setting.default_language = 'en'
     @request.env['HTTP_ACCEPT_LANGUAGE'] = 'fr,fr-fr;q=0.8,en-us;q=0.5,en;q=0.3'
     get :index
     assert_equal :fr, @controller.current_language
   end
 
   def test_browser_language_alternate
-    Setting.default_language = 'en'
     @request.env['HTTP_ACCEPT_LANGUAGE'] = 'zh-TW'
     get :index
     assert_equal :"zh-TW", @controller.current_language
   end
 
   def test_browser_language_alternate_not_valid
-    Setting.default_language = 'en'
     @request.env['HTTP_ACCEPT_LANGUAGE'] = 'fr-CA'
     get :index
     assert_equal :fr, @controller.current_language
   end
 
   def test_browser_language_should_be_ignored_with_force_default_language_for_anonymous
-    Setting.default_language = 'en'
     @request.env['HTTP_ACCEPT_LANGUAGE'] = 'fr,fr-fr;q=0.8,en-us;q=0.5,en;q=0.3'
     with_settings :force_default_language_for_anonymous => '1' do
       get :index
@@ -64,20 +59,20 @@ class WelcomeControllerTest < ActionController::TestCase
   end
 
   def test_user_language_should_be_used
-    Setting.default_language = 'fi'
     user = User.find(2).update_attribute :language, 'it'
     @request.session[:user_id] = 2
     @request.env['HTTP_ACCEPT_LANGUAGE'] = 'fr,fr-fr;q=0.8,en-us;q=0.5,en;q=0.3'
-    get :index
-    assert_equal :it, @controller.current_language
+    with_settings :default_language => 'fi' do
+      get :index
+      assert_equal :it, @controller.current_language
+    end
   end
 
   def test_user_language_should_be_ignored_if_force_default_language_for_loggedin
-    Setting.default_language = 'fi'
     user = User.find(2).update_attribute :language, 'it'
     @request.session[:user_id] = 2
     @request.env['HTTP_ACCEPT_LANGUAGE'] = 'fr,fr-fr;q=0.8,en-us;q=0.5,en;q=0.3'
-    with_settings :force_default_language_for_loggedin => '1' do
+    with_settings :force_default_language_for_loggedin => '1', :default_language => 'fi' do
       get :index
       assert_equal :fi, @controller.current_language
     end
@@ -107,16 +102,14 @@ class WelcomeControllerTest < ActionController::TestCase
     @request.session[:user_id] = 2
 
     get :index
-    assert_no_tag 'script',
-      :attributes => {:type => "text/javascript"},
-      :content => %r{warnLeavingUnsaved}
+    assert_select 'script', :text => %r{warnLeavingUnsaved}, :count => 0
   end
 
   def test_logout_link_should_post
     @request.session[:user_id] = 2
 
     get :index
-    assert_select 'a[href=/logout][data-method=post]', :text => 'Sign out'
+    assert_select 'a[href="/logout"][data-method=post]', :text => 'Sign out'
   end
 
   def test_call_hook_mixed_in
@@ -129,7 +122,7 @@ class WelcomeControllerTest < ActionController::TestCase
 
     get :index
     assert_select "#header select" do
-      assert_select "option", :text => 'Foo &amp; Bar'
+      assert_select "option", :text => 'Foo & Bar'
     end
   end
 
