@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2015  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -20,10 +20,6 @@ require File.expand_path('../../../test_helper', __FILE__)
 class Redmine::ApiTest::ApiTest < Redmine::ApiTest::Base
   fixtures :users
 
-  def setup
-    Setting.rest_api_enabled = '1'
-  end
-
   def test_api_should_work_with_protect_from_forgery
     ActionController::Base.allow_forgery_protection = true
     assert_difference('User.count') do
@@ -38,4 +34,14 @@ class Redmine::ApiTest::ApiTest < Redmine::ApiTest::Base
   ensure
     ActionController::Base.allow_forgery_protection = false
   end
-end
\ No newline at end of file
+
+  def test_json_datetime_format
+    get '/users/1.json', {}, credentials('admin')
+    assert_include '"created_on":"2006-07-19T17:12:21Z"', response.body
+  end
+
+  def test_xml_datetime_format
+    get '/users/1.xml', {}, credentials('admin')
+    assert_include '<created_on>2006-07-19T17:12:21Z</created_on>', response.body
+  end
+end
