@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -18,57 +18,33 @@
 require File.expand_path('../../../test_helper', __FILE__)
 
 class Redmine::ApiTest::UsersTest < Redmine::ApiTest::Base
-  fixtures :users, :members, :member_roles, :roles, :projects
+  fixtures :users, :email_addresses, :members, :member_roles, :roles, :projects
 
-  def setup
-    Setting.rest_api_enabled = '1'
+  test "GET /users.xml should return users" do
+    get '/users.xml', {}, credentials('admin')
+
+    assert_response :success
+    assert_equal 'application/xml', response.content_type
+    assert_select 'users' do
+      assert_select 'user', assigns(:users).size
+    end
   end
 
-  should_allow_api_authentication(:get, "/users.xml")
-  should_allow_api_authentication(:get, "/users.json")
-  should_allow_api_authentication(:post,
-    '/users.xml',
-     {:user => {
-        :login => 'foo', :firstname => 'Firstname', :lastname => 'Lastname',
-        :mail => 'foo@example.net', :password => 'secret123'
-      }},
-    {:success_code => :created})
-  should_allow_api_authentication(:post,
-    '/users.json',
-    {:user => {
-       :login => 'foo', :firstname => 'Firstname', :lastname => 'Lastname',
-       :mail => 'foo@example.net'
-    }},
-    {:success_code => :created})
-  should_allow_api_authentication(:put,
-    '/users/2.xml',
-    {:user => {
-        :login => 'jsmith', :firstname => 'John', :lastname => 'Renamed',
-        :mail => 'jsmith@somenet.foo'
-    }},
-    {:success_code => :ok})
-  should_allow_api_authentication(:put,
-    '/users/2.json',
-    {:user => {
-        :login => 'jsmith', :firstname => 'John', :lastname => 'Renamed',
-        :mail => 'jsmith@somenet.foo'
-    }},
-    {:success_code => :ok})
-  should_allow_api_authentication(:delete,
-    '/users/2.xml',
-    {},
-    {:success_code => :ok})
-  should_allow_api_authentication(:delete,
-    '/users/2.xml',
-    {},
-    {:success_code => :ok})
+  test "GET /users.json should return users" do
+    get '/users.json', {}, credentials('admin')
+
+    assert_response :success
+    assert_equal 'application/json', response.content_type
+    json = ActiveSupport::JSON.decode(response.body)
+    assert json.key?('users')
+    assert_equal assigns(:users).size, json['users'].size
+  end
 
   test "GET /users/:id.xml should return the user" do
     get '/users/2.xml'
 
     assert_response :success
-    assert_tag :tag => 'user',
-      :child => {:tag => 'id', :content => '2'}
+    assert_select 'user id', :text => '2'
   end
 
   test "GET /users/:id.json should return the user" do
@@ -85,9 +61,7 @@ class Redmine::ApiTest::UsersTest < Redmine::ApiTest::Base
     get '/users/2.xml?include=memberships'
 
     assert_response :success
-    assert_tag :tag => 'memberships',
-      :parent => {:tag => 'user'},
-      :children => {:count => 1}
+    assert_select 'user memberships', 1
   end
 
   test "GET /users/:id.json with include=memberships should include memberships" do
@@ -112,44 +86,43 @@ class Redmine::ApiTest::UsersTest < Redmine::ApiTest::Base
   test "GET /users/current.xml should return current user" do
     get '/users/current.xml', {}, credentials('jsmith')
 
-    assert_tag :tag => 'user',
-      :child => {:tag => 'id', :content => '2'}
+    assert_select 'user id', :text => '2'
   end
 
   test "GET /users/:id should not return login for other user" do
     get '/users/3.xml', {}, credentials('jsmith')
     assert_response :success
-    assert_no_tag 'user', :child => {:tag => 'login'}
+    assert_select 'user login', 0
   end
 
   test "GET /users/:id should return login for current user" do
     get '/users/2.xml', {}, credentials('jsmith')
     assert_response :success
-    assert_tag 'user', :child => {:tag => 'login', :content => 'jsmith'}
+    assert_select 'user login', :text => 'jsmith'
   end
 
   test "GET /users/:id should not return api_key for other user" do
     get '/users/3.xml', {}, credentials('jsmith')
     assert_response :success
-    assert_no_tag 'user', :child => {:tag => 'api_key'}
+    assert_select 'user api_key', 0
   end
 
   test "GET /users/:id should return api_key for current user" do
     get '/users/2.xml', {}, credentials('jsmith')
     assert_response :success
-    assert_tag 'user', :child => {:tag => 'api_key', :content => User.find(2).api_key}
+    assert_select 'user api_key', :text => User.find(2).api_key
   end
 
   test "GET /users/:id should not return status for standard user" do
     get '/users/3.xml', {}, credentials('jsmith')
     assert_response :success
-    assert_no_tag 'user', :child => {:tag => 'status'}
+    assert_select 'user status', 0
   end
 
   test "GET /users/:id should return status for administrators" do
     get '/users/2.xml', {}, credentials('admin')
     assert_response :success
-    assert_tag 'user', :child => {:tag => 'status', :content => User.find(1).status.to_s}
+    assert_select 'user status', :text => User.find(1).status.to_s
   end
 
   test "POST /users.xml with valid parameters should create the user" do
@@ -174,7 +147,7 @@ class Redmine::ApiTest::UsersTest < Redmine::ApiTest::Base
 
     assert_response :created
     assert_equal 'application/xml', @response.content_type
-    assert_tag 'user', :child => {:tag => 'id', :content => user.id.to_s}
+    assert_select 'user id', :text => user.id.to_s
   end
 
   test "POST /users.json with valid parameters should create the user" do
@@ -210,10 +183,7 @@ class Redmine::ApiTest::UsersTest < Redmine::ApiTest::Base
 
     assert_response :unprocessable_entity
     assert_equal 'application/xml', @response.content_type
-    assert_tag 'errors', :child => {
-                           :tag => 'error',
-                           :content => "First name can't be blank"
-                         }
+    assert_select 'errors error', :text => "First name cannot be blank"
   end
 
   test "POST /users.json with with invalid parameters should return errors" do
@@ -283,10 +253,7 @@ class Redmine::ApiTest::UsersTest < Redmine::ApiTest::Base
 
     assert_response :unprocessable_entity
     assert_equal 'application/xml', @response.content_type
-    assert_tag 'errors', :child => {
-                           :tag => 'error',
-                           :content => "First name can't be blank"
-                          }
+    assert_select 'errors error', :text => "First name cannot be blank"
   end
 
   test "PUT /users/:id.json with invalid parameters" do
