@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,11 +17,8 @@
 
 require File.expand_path('../../../test_helper', __FILE__)
 
-class RoutingAutoCompletesTest < ActionDispatch::IntegrationTest
+class RoutingAutoCompletesTest < Redmine::RoutingTest
   def test_auto_completes
-    assert_routing(
-        { :method => 'get', :path => "/issues/auto_complete" },
-        { :controller => 'auto_completes', :action => 'issues' }
-      )
+    should_route 'GET /issues/auto_complete' => 'auto_completes#issues'
   end
 end
