@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -22,10 +22,13 @@ require File.expand_path('../../test_helper', __FILE__)
 class ChangesetTest < ActiveSupport::TestCase
   fixtures :projects, :repositories,
            :issues, :issue_statuses, :issue_categories,
+           :journals, :journal_details,
+           :workflows,
            :changesets, :changes,
            :enumerations,
            :custom_fields, :custom_values,
            :users, :members, :member_roles,
+           :email_addresses,
            :trackers, :projects_trackers,
            :enabled_modules, :roles
 
@@ -162,6 +165,42 @@ class ChangesetTest < ActiveSupport::TestCase
     assert_equal [1,2,3], c.issue_ids.sort
   end
 
+  def test_ref_keywords_with_large_number_should_not_error
+    Setting.commit_ref_keywords = '*'
+    c = Changeset.new(:repository   => Project.find(1).repository,
+                      :committed_on => Time.now,
+                      :comments     => 'Out of range #2010021810000121',
+                      :revision     => '12345')
+    assert_nothing_raised do
+      assert c.save
+    end
+    assert_equal [], c.issue_ids.sort
+  end
+
+  def test_update_keywords_with_changes_should_create_journal
+    issue = Issue.generate!(:project_id => 1, :status_id => 1)
+
+    with_settings :commit_update_keywords => [{'keywords' => 'fixes', 'status_id' => '3'}] do
+      assert_difference 'Journal.count' do
+        c = Changeset.generate!(:repository => Project.find(1).repository,:comments => "Fixes ##{issue.id}")
+        assert_include c.id, issue.reload.changeset_ids
+        journal = Journal.order('id DESC').first
+        assert_equal 1, journal.details.count
+      end
+    end
+  end
+
+  def test_update_keywords_without_change_should_not_create_journal
+    issue = Issue.generate!(:project_id => 1, :status_id => 3)
+
+    with_settings :commit_update_keywords => [{'keywords' => 'fixes', 'status_id' => '3'}] do
+      assert_no_difference 'Journal.count' do
+        c = Changeset.generate!(:repository => Project.find(1).repository,:comments => "Fixes ##{issue.id}")
+        assert_include c.id, issue.reload.changeset_ids
+      end
+    end
+  end
+
   def test_update_keywords_with_multiple_rules
     with_settings :commit_update_keywords => [
       {'keywords' => 'fixes, closes', 'status_id' => '5'},
@@ -176,7 +215,7 @@ class ChangesetTest < ActiveSupport::TestCase
     end
   end
 
-  def test_update_keywords_with_multiple_rules_should_match_tracker
+  def test_update_keywords_with_multiple_rules_for_the_same_keyword_should_match_tracker
     with_settings :commit_update_keywords => [
       {'keywords' => 'fixes', 'status_id' => '5', 'if_tracker_id' => '2'},
       {'keywords' => 'fixes', 'status_id' => '3', 'if_tracker_id' => ''}
@@ -190,6 +229,24 @@ class ChangesetTest < ActiveSupport::TestCase
     end
   end
 
+  def test_update_keywords_with_multiple_rules_for_the_same_tracker_should_match_keyword
+    with_settings :commit_update_keywords => [
+      {'keywords' => 'Fixes, Closes', 'status_id' => '5', 'done_ratio' => '100', 'if_tracker_id' => '2'},
+      {'keywords' => 'Testing',       'status_id' => '3', 'done_ratio' => '90',  'if_tracker_id' => '2'}
+    ] do
+
+      issue1 = Issue.generate!(:tracker_id => 2)
+      issue2 = Issue.generate!(:tracker_id => 2)
+      Changeset.generate!(:comments => "Testing ##{issue1.id}, Fixes ##{issue2.id}")
+      issue1.reload
+      assert_equal 3, issue1.status_id
+      assert_equal 90, issue1.done_ratio
+      issue2.reload
+      assert_equal 5, issue2.status_id
+      assert_equal 100, issue2.done_ratio
+    end
+  end
+
   def test_update_keywords_with_multiple_rules_and_no_match
     with_settings :commit_update_keywords => [
       {'keywords' => 'fixes', 'status_id' => '5', 'if_tracker_id' => '2'},
@@ -297,6 +354,17 @@ class ChangesetTest < ActiveSupport::TestCase
     assert_equal 0, issue.done_ratio
   end
 
+  def test_2_repositories_with_same_backend_should_not_link_issue_multiple_times
+    Setting.commit_ref_keywords = '*'
+    r1 = Repository::Subversion.create!(:project_id => 1, :identifier => 'svn1', :url => 'file:///svn1')
+    r2 = Repository::Subversion.create!(:project_id => 1, :identifier => 'svn2', :url => 'file:///svn1')
+    now = Time.now
+    assert_difference 'Issue.find(1).changesets.count' do
+      c1 = Changeset.create!(:repository => r1, :committed_on => now, :comments => 'Fixes #1', :revision => '12345')
+      c1 = Changeset.create!(:repository => r2, :committed_on => now, :comments => 'Fixes #1', :revision => '12345')
+    end
+  end
+
   def test_text_tag_revision
     c = Changeset.new(:revision => '520')
     assert_equal 'r520', c.text_tag
