@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -20,15 +20,25 @@ require File.expand_path('../../test_helper', __FILE__)
 class CustomValueTest < ActiveSupport::TestCase
   fixtures :custom_fields, :custom_values, :users
 
-  def test_default_value
-    field = CustomField.find_by_default_value('Default string')
-    assert_not_nil field
+  def test_new_without_value_should_set_default_value
+    field = CustomField.generate!(:default_value => 'Default string')
 
     v = CustomValue.new(:custom_field => field)
     assert_equal 'Default string', v.value
+  end
 
-    v = CustomValue.new(:custom_field => field, :value => 'Not empty')
-    assert_equal 'Not empty', v.value
+  def test_new_with_value_should_not_set_default_value
+    field = CustomField.generate!(:default_value => 'Default string')
+
+    v = CustomValue.new(:custom_field => field, :value => 'String')
+    assert_equal 'String', v.value
+  end
+
+  def test_new_with_nil_value_should_not_set_default_value
+    field = CustomField.generate!(:default_value => 'Default string')
+
+    v = CustomValue.new(:custom_field => field, :value => nil)
+    assert_nil v.value
   end
 
   def test_sti_polymorphic_association
