@@ -55,25 +55,6 @@ class IssuePriorityTest < ActiveSupport::TestCase
     assert_equal [1, 2, 3], priorities.map(&:position)
   end
 
-  def test_reset_positions_in_list_should_set_sequential_positions
-    IssuePriority.delete_all
-
-    priorities = [1, 2, 3].map {|i| IssuePriority.create!(:name => "P#{i}")}
-    priorities[0].update_attribute :position, 4
-    priorities[1].update_attribute :position, 2
-    priorities[2].update_attribute :position, 7
-    assert_equal [4, 2, 7], priorities.map(&:reload).map(&:position)
-
-    priorities[0].reset_positions_in_list
-    assert_equal [2, 1, 3], priorities.map(&:reload).map(&:position)
-  end
-
-  def test_moving_in_list_should_reset_positions
-    priority = IssuePriority.first
-    priority.expects(:reset_positions_in_list).once
-    priority.move_to = 'higher'
-  end
-
   def test_clear_position_names_should_set_position_names_to_nil
     IssuePriority.clear_position_names
     assert IssuePriority.all.all? {|priority| priority.position_name.nil?}
@@ -101,7 +82,8 @@ class IssuePriorityTest < ActiveSupport::TestCase
 
   def test_moving_a_priority_should_update_position_names
     prio = IssuePriority.first
-    prio.move_to = 'lowest'
+    prio.position = IssuePriority.count
+    prio.save!
     prio.reload
     assert_equal 'highest', prio.position_name
   end
