@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -20,6 +20,7 @@ require File.expand_path('../../../../test_helper', __FILE__)
 class Redmine::Hook::ManagerTest < ActionView::TestCase
   fixtures :projects, :users, :members, :member_roles, :roles,
            :groups_users,
+           :email_addresses,
            :trackers, :projects_trackers,
            :enabled_modules,
            :versions,
@@ -113,6 +114,15 @@ class Redmine::Hook::ManagerTest < ActionView::TestCase
     assert_equal ['<a href="/issues">Issues</a>'], hook_helper.call_hook(:view_layouts_base_html_head)
   end
 
+  def test_view_hook_should_generate_links_with_relative_url_root
+    Redmine::Utils.relative_url_root = '/foo'
+    @hook_module.add_listener(TestLinkToHook)
+
+    assert_equal ['<a href="/foo/issues">Issues</a>'], hook_helper.call_hook(:view_layouts_base_html_head)
+  ensure
+    Redmine::Utils.relative_url_root = ''
+  end
+
   # Context: Redmine::Hook::Helper.call_hook
   def test_call_hook_with_project_added_to_context
     @hook_module.add_listener(TestHook3)
