@@ -1,3 +1,5 @@
+# encoding: utf-8
+#
 # Redmine - project management software
 # Copyright (C) 2006-2016  Jean-Philippe Lang
 #
@@ -142,15 +144,14 @@ class QueryTest < ActiveSupport::TestCase
   def test_query_should_allow_shared_versions_for_a_project_query
     subproject_version = Version.find(4)
     query = IssueQuery.new(:project => Project.find(1), :name => '_')
-    query.add_filter('fixed_version_id', '=', [subproject_version.id.to_s])
-
-    assert query.statement.include?("#{Issue.table_name}.fixed_version_id IN ('4')")
+    filter = query.available_filters["fixed_version_id"]
+    assert_not_nil filter
+    assert_include subproject_version.id.to_s, filter[:values].map(&:last)
   end
 
   def test_query_with_multiple_custom_fields
     query = IssueQuery.find(1)
     assert query.valid?
-    assert query.statement.include?("#{CustomValue.table_name}.value IN ('MySQL')")
     issues = find_issues_with_query(query)
     assert_equal 1, issues.length
     assert_equal Issue.find(3), issues.first
@@ -234,6 +235,22 @@ class QueryTest < ActiveSupport::TestCase
     assert_equal 2, issues.first.id
   end
 
+  def test_operator_is_on_issue_id_should_accept_comma_separated_values
+    query = IssueQuery.new(:name => '_')
+    query.add_filter("issue_id", '=', ['1,3'])
+    issues = find_issues_with_query(query)
+    assert_equal 2, issues.size
+    assert_equal [1,3], issues.map(&:id).sort
+  end
+
+  def test_operator_between_on_issue_id_should_return_range
+    query = IssueQuery.new(:name => '_')
+    query.add_filter("issue_id", '><', ['2','3'])
+    issues = find_issues_with_query(query)
+    assert_equal 2, issues.size
+    assert_equal [2,3], issues.map(&:id).sort
+  end
+
   def test_operator_is_on_integer_custom_field
     f = IssueCustomField.create!(:name => 'filter', :field_format => 'int', :is_for_all => true, :is_filter => true, :trackers => Tracker.all)
     CustomValue.create!(:custom_field => f, :customized => Issue.find(1), :value => '7')
@@ -326,6 +343,16 @@ class QueryTest < ActiveSupport::TestCase
     assert issues.map(&:id).include?(3)
   end
 
+  def test_operator_is_on_string_custom_field_with_utf8_value
+    f = IssueCustomField.create!(:name => 'filter', :field_format => 'string', :is_filter => true, :is_for_all => true, :trackers => Tracker.all)
+    CustomValue.create!(:custom_field => f, :customized => Issue.find(1), :value => 'Kiá»ƒm')
+
+    query = IssueQuery.new(:name => '_')
+    query.add_filter("cf_#{f.id}", '=', ['Kiá»ƒm'])
+    issues = find_issues_with_query(query)
+    assert_equal [1], issues.map(&:id).sort
+  end
+
   def test_operator_is_on_is_private_field
     # is_private filter only available for those who can set issues private
     User.current = User.find(2)
@@ -602,6 +629,16 @@ class QueryTest < ActiveSupport::TestCase
     result.each {|issue| assert issue.subject.downcase.include?('cdef') }
   end
 
+  def test_operator_contains_with_utf8_string
+    issue = Issue.generate!(:subject => 'Subject contains Kiểm')
+
+    query = IssueQuery.new(:name => '_')
+    query.add_filter('subject', '~', ['Kiểm'])
+    result = find_issues_with_query(query)
+    assert_include issue, result
+    assert_equal 1, result.size
+  end
+
   def test_operator_does_not_contain
     issue = Issue.generate!(:subject => 'AbCdEfG')
 
@@ -1573,7 +1610,6 @@ class QueryTest < ActiveSupport::TestCase
     setup_member_of_group
     @query.add_filter('member_of_group', '=', [@group.id.to_s])
 
-    assert_query_statement_includes @query, "#{Issue.table_name}.assigned_to_id IN ('#{@user_in_group.id}','#{@second_user_in_group.id}','#{@group.id}')"
     assert_find_issues_with_query_is_successful @query
   end
 
@@ -1581,8 +1617,6 @@ class QueryTest < ActiveSupport::TestCase
     setup_member_of_group
     @query.add_filter('member_of_group', '!*', [''])
 
-    # Users not in a group
-    assert_query_statement_includes @query, "#{Issue.table_name}.assigned_to_id IS NULL OR #{Issue.table_name}.assigned_to_id NOT IN ('#{@user_in_group.id}','#{@second_user_in_group.id}','#{@user_in_group2.id}','#{@group.id}','#{@group2.id}')"
     assert_find_issues_with_query_is_successful @query
   end
 
@@ -1590,8 +1624,6 @@ class QueryTest < ActiveSupport::TestCase
     setup_member_of_group
     @query.add_filter('member_of_group', '*', [''])
 
-    # Only users in a group
-    assert_query_statement_includes @query, "#{Issue.table_name}.assigned_to_id IN ('#{@user_in_group.id}','#{@second_user_in_group.id}','#{@user_in_group2.id}','#{@group.id}','#{@group2.id}')"
     assert_find_issues_with_query_is_successful @query
   end
 
@@ -1696,4 +1728,50 @@ class QueryTest < ActiveSupport::TestCase
     c = QueryColumn.new('foo', :caption => lambda {'Foo'})
     assert_equal 'Foo', c.caption
   end
+
+  def test_date_clause_should_respect_user_time_zone_with_local_default
+    @query = IssueQuery.new(:name => '_')
+
+    # user is in Hawaii (-10)
+    User.current = users(:users_001)
+    User.current.pref.update_attribute :time_zone, 'Hawaii'
+
+    # assume timestamps are stored in server local time
+    local_zone = Time.zone
+
+    from = Date.parse '2016-03-20'
+    to = Date.parse '2016-03-22'
+    assert c = @query.send(:date_clause, 'table', 'field', from, to, false)
+
+    # the dates should have been interpreted in the user's time zone and
+    # converted to local time
+    # what we get exactly in the sql depends on the local time zone, therefore
+    # it's computed here.
+    f = User.current.time_zone.local(from.year, from.month, from.day).yesterday.end_of_day.in_time_zone(local_zone)
+    t = User.current.time_zone.local(to.year, to.month, to.day).end_of_day.in_time_zone(local_zone)
+    assert_equal "table.field > '#{Query.connection.quoted_date f}' AND table.field <= '#{Query.connection.quoted_date t}'", c
+  end
+
+  def test_date_clause_should_respect_user_time_zone_with_utc_default
+    @query = IssueQuery.new(:name => '_')
+
+    # user is in Hawaii (-10)
+    User.current = users(:users_001)
+    User.current.pref.update_attribute :time_zone, 'Hawaii'
+
+    # assume timestamps are stored as utc
+    ActiveRecord::Base.default_timezone = :utc
+
+    from = Date.parse '2016-03-20'
+    to = Date.parse '2016-03-22'
+    assert c = @query.send(:date_clause, 'table', 'field', from, to, false)
+    # the dates should have been interpreted in the user's time zone and
+    # converted to utc. March 20 in Hawaii begins at 10am UTC.
+    f = Time.new(2016, 3, 20, 9, 59, 59, 0).end_of_hour
+    t = Time.new(2016, 3, 23, 9, 59, 59, 0).end_of_hour
+    assert_equal "table.field > '#{Query.connection.quoted_date f}' AND table.field <= '#{Query.connection.quoted_date t}'", c
+  ensure
+    ActiveRecord::Base.default_timezone = :local # restore Redmine default
+  end
+
 end
