@@ -496,4 +496,18 @@ class RepositoryTest < ActiveSupport::TestCase
     Repository::Subversion.any_instance.expects(:fetch_changesets).twice.returns(true)
     Repository.fetch_changesets
   end
+
+  def test_repository_class
+    assert_equal Repository::Subversion, Repository.repository_class('Subversion')
+    assert_equal Repository::Git, Repository.repository_class('Git')
+    assert_nil Repository.factory('Serializer')
+    assert_nil Repository.factory('Query')
+  end
+
+  def test_factory
+    assert_instance_of Repository::Subversion, Repository.factory('Subversion')
+    assert_instance_of Repository::Git, Repository.factory('Git')
+    assert_nil Repository.factory('Serializer')
+    assert_nil Repository.factory('Query')
+  end
 end
