@@ -1,5 +1,7 @@
+# encoding: utf-8
+#
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2016  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -22,10 +24,13 @@ class SearchTest < ActiveSupport::TestCase
            :members,
            :member_roles,
            :projects,
+           :projects_trackers,
            :roles,
            :enabled_modules,
            :issues,
            :trackers,
+           :issue_statuses,
+           :enumerations,
            :journals,
            :journal_details,
            :repositories,
@@ -42,25 +47,25 @@ class SearchTest < ActiveSupport::TestCase
   def test_search_by_anonymous
     User.current = nil
 
-    r = Issue.search(@issue_keyword).first
+    r = Issue.search_results(@issue_keyword)
     assert r.include?(@issue)
-    r = Changeset.search(@changeset_keyword).first
+    r = Changeset.search_results(@changeset_keyword)
     assert r.include?(@changeset)
 
     # Removes the :view_changesets permission from Anonymous role
     remove_permission Role.anonymous, :view_changesets
     User.current = nil
 
-    r = Issue.search(@issue_keyword).first
+    r = Issue.search_results(@issue_keyword)
     assert r.include?(@issue)
-    r = Changeset.search(@changeset_keyword).first
+    r = Changeset.search_results(@changeset_keyword)
     assert !r.include?(@changeset)
 
     # Make the project private
     @project.update_attribute :is_public, false
-    r = Issue.search(@issue_keyword).first
+    r = Issue.search_results(@issue_keyword)
     assert !r.include?(@issue)
-    r = Changeset.search(@changeset_keyword).first
+    r = Changeset.search_results(@changeset_keyword)
     assert !r.include?(@changeset)
   end
 
@@ -68,25 +73,25 @@ class SearchTest < ActiveSupport::TestCase
     User.current = User.find_by_login('rhill')
     assert User.current.memberships.empty?
 
-    r = Issue.search(@issue_keyword).first
+    r = Issue.search_results(@issue_keyword)
     assert r.include?(@issue)
-    r = Changeset.search(@changeset_keyword).first
+    r = Changeset.search_results(@changeset_keyword)
     assert r.include?(@changeset)
 
     # Removes the :view_changesets permission from Non member role
     remove_permission Role.non_member, :view_changesets
     User.current = User.find_by_login('rhill')
 
-    r = Issue.search(@issue_keyword).first
+    r = Issue.search_results(@issue_keyword)
     assert r.include?(@issue)
-    r = Changeset.search(@changeset_keyword).first
+    r = Changeset.search_results(@changeset_keyword)
     assert !r.include?(@changeset)
 
     # Make the project private
     @project.update_attribute :is_public, false
-    r = Issue.search(@issue_keyword).first
+    r = Issue.search_results(@issue_keyword)
     assert !r.include?(@issue)
-    r = Changeset.search(@changeset_keyword).first
+    r = Changeset.search_results(@changeset_keyword)
     assert !r.include?(@changeset)
   end
 
@@ -94,16 +99,16 @@ class SearchTest < ActiveSupport::TestCase
     User.current = User.find_by_login('jsmith')
     assert User.current.projects.include?(@project)
 
-    r = Issue.search(@issue_keyword).first
+    r = Issue.search_results(@issue_keyword)
     assert r.include?(@issue)
-    r = Changeset.search(@changeset_keyword).first
+    r = Changeset.search_results(@changeset_keyword)
     assert r.include?(@changeset)
 
     # Make the project private
     @project.update_attribute :is_public, false
-    r = Issue.search(@issue_keyword).first
+    r = Issue.search_results(@issue_keyword)
     assert r.include?(@issue)
-    r = Changeset.search(@changeset_keyword).first
+    r = Changeset.search_results(@changeset_keyword)
     assert r.include?(@changeset)
   end
 
@@ -115,26 +120,82 @@ class SearchTest < ActiveSupport::TestCase
     User.current = User.find_by_login('jsmith')
     assert User.current.projects.include?(@project)
 
-    r = Issue.search(@issue_keyword).first
+    r = Issue.search_results(@issue_keyword)
     assert r.include?(@issue)
-    r = Changeset.search(@changeset_keyword).first
+    r = Changeset.search_results(@changeset_keyword)
     assert !r.include?(@changeset)
 
     # Make the project private
     @project.update_attribute :is_public, false
-    r = Issue.search(@issue_keyword).first
+    r = Issue.search_results(@issue_keyword)
     assert r.include?(@issue)
-    r = Changeset.search(@changeset_keyword).first
+    r = Changeset.search_results(@changeset_keyword)
     assert !r.include?(@changeset)
   end
 
   def test_search_issue_with_multiple_hits_in_journals
-    i = Issue.find(1)
-    assert_equal 2, i.journals.where("notes LIKE '%notes%'").count
+    issue = Issue.find(1)
+    assert_equal 2, issue.journals.where("notes LIKE '%notes%'").count
 
-    r = Issue.search('%notes%').first
+    r = Issue.search_results('%notes%')
     assert_equal 1, r.size
-    assert_equal i, r.first
+    assert_equal issue, r.first
+  end
+
+  def test_search_should_be_case_insensitive
+    issue = Issue.generate!(:subject => "AzerTY")
+
+    r = Issue.search_results('AZERty')
+    assert_include issue, r
+  end
+
+  def test_search_should_be_case_insensitive_with_accented_characters
+    unless sqlite?
+      issue1 = Issue.generate!(:subject => "Special chars: ÖÖ")
+      issue2 = Issue.generate!(:subject => "Special chars: Öö")
+  
+      r = Issue.search_results('ÖÖ')
+      assert_include issue1, r
+      assert_include issue2, r
+    end
+  end
+
+  def test_search_should_be_case_and_accent_insensitive_with_mysql
+    if mysql?
+      issue1 = Issue.generate!(:subject => "OO")
+      issue2 = Issue.generate!(:subject => "oo")
+  
+      r = Issue.search_results('ÖÖ')
+      assert_include issue1, r
+      assert_include issue2, r
+    end
+  end
+
+  def test_search_should_be_case_and_accent_insensitive_with_postgresql_and_noaccent_extension
+    if postgresql?
+      skip unless Redmine::Database.postgresql_version >= 90000
+      # Extension will be rollbacked with the test transaction
+      ActiveRecord::Base.connection.execute("CREATE EXTENSION IF NOT EXISTS unaccent")
+      Redmine::Database.reset
+      assert Redmine::Database.postgresql_unaccent?
+
+      issue1 = Issue.generate!(:subject => "OO")
+      issue2 = Issue.generate!(:subject => "oo")
+  
+      r = Issue.search_results('ÖÖ')
+      assert_include issue1, r
+      assert_include issue2, r
+    end
+  ensure
+    Redmine::Database.reset
+  end
+
+  def test_fetcher_should_handle_accents_in_phrases
+    f = Redmine::Search::Fetcher.new('No special chars "in a phrase"', User.anonymous, %w(issues), Project.all)
+    assert_equal ['No', 'special', 'chars', 'in a phrase'], f.tokens
+
+    f = Redmine::Search::Fetcher.new('Special chars "in a phrase Öö"', User.anonymous, %w(issues), Project.all)
+    assert_equal ['Special', 'chars', 'in a phrase Öö'], f.tokens
   end
 
   private
