@@ -18,7 +18,7 @@
 require File.expand_path('../../test_helper', __FILE__)
 
 class TrackerTest < ActiveSupport::TestCase
-  fixtures :trackers, :workflows, :issue_statuses, :roles, :issues
+  fixtures :trackers, :workflows, :issue_statuses, :roles, :issues, :projects, :projects_trackers
 
   def test_sorted_scope
     assert_equal Tracker.all.sort, Tracker.sorted.to_a
@@ -28,6 +28,18 @@ class TrackerTest < ActiveSupport::TestCase
     assert_equal Tracker.find_by_name('Feature'), Tracker.named('feature').first
   end
 
+  def test_visible_scope_chained_with_project_rolled_up_trackers
+    project = Project.find(1)
+    role = Role.generate!
+    role.add_permission! :view_issues
+    role.set_permission_trackers :view_issues, [2]
+    role.save!
+    user = User.generate!
+    User.add_to_project user, project, role
+
+    assert_equal [2], project.rolled_up_trackers(false).visible(user).map(&:id)
+  end
+
   def test_copy_workflows
     source = Tracker.find(1)
     rules_count = source.workflow_rules.count
